CardElementChangeEvent class

Annotations
  • @freezed

Constructors

CardElementChangeEvent({required String elementType, required bool empty, required bool complete, StripeError? error, required String brand, CardElementChangeEventValue? value})
const
factory
CardElementChangeEvent.fromJson(Map<String, dynamic> json)
factory

Properties

brand → String
no setterinherited
complete → bool
no setterinherited
copyWith → $CardElementChangeEventCopyWith<CardElementChangeEvent>
Create a copy of CardElementChangeEvent with the given fields replaced by the non-null parameter values.
no setterinherited
elementType → String
no setterinherited
empty → bool
no setterinherited
error → StripeError?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → CardElementChangeEventValue?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CardElementChangeEvent to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited