CardElementClasses class

Annotations
  • @freezed

Constructors

CardElementClasses({String? base, String? complete, String? empty, String? focus, String? invalid, bool? webkitAutofill})
const
factory
CardElementClasses.fromJson(Map<String, dynamic> json)
factory

Properties

base → String?
The base class applied to the container. Defaults to StripeElement.
no setterinherited
complete → String?
The class name to apply when the Element is complete. Defaults to StripeElement--complete
no setterinherited
copyWith → $CardElementClassesCopyWith<CardElementClasses>
Create a copy of CardElementClasses with the given fields replaced by the non-null parameter values.
no setterinherited
empty → String?
The class name to apply when the Element is empty. Defaults to StripeElement--empty.
no setterinherited
focus → String?
The class name to apply when the Element is focus. Defaults to StripeElement--focus.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invalid → String?
The class name to apply when the Element is invalid. Defaults to StripeElement--invalid.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webkitAutofill → bool?
The class name to apply when the Element has its value autofilled by the browser (only on Chrome and Safari). Defaults to StripeElement--webkit-autofill.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CardElementClasses to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited