CardElementOptions class

Annotations
  • @freezed

Constructors

CardElementOptions({CardElementClasses? classes, dynamic style, String? value, bool? hidePostalCode, CardElementIconStyle? iconStyle, bool? hideIcon, bool? disabled})
const
factory
CardElementOptions.fromJson(Map<String, dynamic> json)
factory

Properties

classes → CardElementClasses?
Set custom class names on the container DOM element when the Stripe element is in a particular state.
no setterinherited
copyWith → $CardElementOptionsCopyWith<CardElementOptions>
Create a copy of CardElementOptions with the given fields replaced by the non-null parameter values.
no setterinherited
disabled → bool?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideIcon → bool?
no setterinherited
hidePostalCode → bool?
no setterinherited
iconStyle → CardElementIconStyle?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → dynamic
no setterinherited
value → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CardElementOptions to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited