CardPaymentMethod class

Card data associated with the payment method

Annotations
  • @freezed

Constructors

CardPaymentMethod({String? brand, String? country, int? expYear, int? expMonth, String? funding, String? last4, String? preferredNetwork, List<String>? availableNetworks})
const
factory
CardPaymentMethod.fromJson(Map<String, dynamic> json)
factory

Properties

availableNetworks → List<String>?
The available networks the card can run.
no setterinherited
brand → String?
The brand associated to the card e.g. (visa, amex).
no setterinherited
copyWith → $CardPaymentMethodCopyWith<CardPaymentMethod>
Create a copy of CardPaymentMethod with the given fields replaced by the non-null parameter values.
no setterinherited
country → String?
Two letter iso code.
no setterinherited
expMonth → int?
two digit number representing the month of expire of the card.
no setterinherited
expYear → int?
four digit number representing the year of expiry of the card.
no setterinherited
funding → String?
card funding type e.g. (credit, debit).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
last4 → String?
last four digits of the card.
no setterinherited
preferredNetwork → String?
The preffered card brand for payment
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CardPaymentMethod to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited