CollectBankAccountForPaymentMethodData class abstract

Available extensions
Annotations
  • @freezed

Constructors

CollectBankAccountForPaymentMethodData({@JsonKey.new(name: 'billing_details') BillingDetails? billingDetails})
const
factory
CollectBankAccountForPaymentMethodData.fromJson(Map<String, dynamic> json)
factory

Properties

billingDetails BillingDetails?
Billing details for the payment method.
no setterinherited
copyWith → $CollectBankAccountForPaymentMethodDataCopyWith<CollectBankAccountForPaymentMethodData>
Create a copy of CollectBankAccountForPaymentMethodData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CollectBankAccountForPaymentMethodData value)) → TResult

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CollectBankAccountForPaymentMethodData value)?) → TResult?

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CollectBankAccountForPaymentMethodData value)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(BillingDetails? billingDetails)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CollectBankAccountForPaymentMethodData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(BillingDetails? billingDetails)) → TResult

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(BillingDetails? billingDetails)?) → TResult?

Available on CollectBankAccountForPaymentMethodData, provided by the CollectBankAccountForPaymentMethodDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited