CollectBankAccountForPaymentParams class abstract

Available extensions
Annotations
  • @freezed

Constructors

CollectBankAccountForPaymentParams({@JsonKey.new(name: 'payment_method_type') required String paymentMethodType, @JsonKey.new(name: 'payment_method_data') CollectBankAccountForPaymentMethodData? paymentMethodData})
const
factory
CollectBankAccountForPaymentParams.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $CollectBankAccountForPaymentParamsCopyWith<CollectBankAccountForPaymentParams>
Create a copy of CollectBankAccountForPaymentParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
paymentMethodData CollectBankAccountForPaymentMethodData?
Payment method data to prefill, including billing details.
no setterinherited
paymentMethodType String
The type of payment method to collect. Currently only us_bank_account is supported.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CollectBankAccountForPaymentParams value)) → TResult

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CollectBankAccountForPaymentParams value)?) → TResult?

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CollectBankAccountForPaymentParams value)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String paymentMethodType, CollectBankAccountForPaymentMethodData? paymentMethodData)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CollectBankAccountForPaymentParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String paymentMethodType, CollectBankAccountForPaymentMethodData? paymentMethodData)) → TResult

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String paymentMethodType, CollectBankAccountForPaymentMethodData? paymentMethodData)?) → TResult?

Available on CollectBankAccountForPaymentParams, provided by the CollectBankAccountForPaymentParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited