CollectBankAccountForSetupParams class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- CollectBankAccountForSetupParams({@JsonKey.new(name: 'payment_method_type') required String paymentMethodType, @JsonKey.new(name: 'payment_method_data') CollectBankAccountForSetupMethodData? paymentMethodData})
-
constfactory
-
CollectBankAccountForSetupParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CollectBankAccountForSetupParamsCopyWith<
CollectBankAccountForSetupParams> -
Create a copy of CollectBankAccountForSetupParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentMethodData → CollectBankAccountForSetupMethodData?
-
Payment method data to prefill, including billing details.
no setterinherited
- paymentMethodType → String
-
The type of payment method to collect. Currently only
us_bank_accountis supported.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CollectBankAccountForSetupParams value)) → TResult -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CollectBankAccountForSetupParams value)?) → TResult? -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CollectBankAccountForSetupParams value)?, {required TResult orElse()}) → TResult -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String paymentMethodType, CollectBankAccountForSetupMethodData? paymentMethodData)?, {required TResult orElse()}) → TResult -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CollectBankAccountForSetupParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String paymentMethodType, CollectBankAccountForSetupMethodData? paymentMethodData)) → TResult -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String paymentMethodType, CollectBankAccountForSetupMethodData? paymentMethodData)?) → TResult? -
Available on CollectBankAccountForSetupParams, provided by the CollectBankAccountForSetupParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited