ConfirmCardSetupData class

Annotations
  • @freezed

Constructors

ConfirmCardSetupData({CardPaymentMethodDetails? paymentMethod, String? returnUrl})
const
factory
ConfirmCardSetupData.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ConfirmCardSetupDataCopyWith<ConfirmCardSetupData>
Create a copy of ConfirmCardSetupData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paymentMethod → CardPaymentMethodDetails?
Either the id of an existing PaymentMethod, or an object containing data to create a PaymentMethod with. See the use case sections below for details.
no setterinherited
returnUrl → String?
If you are handling next actions yourself, pass in a return_url. If the subsequent action is redirect_to_url, this URL will be used on the return path for the redirect.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ConfirmCardSetupData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited