ConfirmP24PaymentData class abstract

Available extensions
Annotations
  • @freezed

Constructors

ConfirmP24PaymentData({@paymentMethodDetailJsonKey P24PaymentMethodDetails? paymentMethod, @JsonKey.new(name: "return_url") String? returnUrl, @JsonKey.new(name: "setup_future_usage") PaymentIntentSetupFutureUsage? setupFutureUsage})
const
factory
ConfirmP24PaymentData.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ConfirmP24PaymentDataCopyWith<ConfirmP24PaymentData>
Create a copy of ConfirmP24PaymentData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paymentMethod → P24PaymentMethodDetails?
Either the ID of an existing PaymentMethod, or an object containing data to create a PaymentMethod with.
no setterinherited
returnUrl → String?
The url your customer will be directed to after they complete authentication.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupFutureUsage → PaymentIntentSetupFutureUsage?
To set up a SEPA Direct Debit payment method using the bank details from this P24 payment, set this parameter to off_session. When using this parameter, a customer will need to be set on the PaymentIntent. The newly created SEPA Direct Debit PaymentMethod will be attached to this customer.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ConfirmP24PaymentData value)) → TResult

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ConfirmP24PaymentData value)?) → TResult?

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ConfirmP24PaymentData value)?, {required TResult orElse()}) → TResult

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(P24PaymentMethodDetails? paymentMethod, String? returnUrl, PaymentIntentSetupFutureUsage? setupFutureUsage)?, {required TResult orElse()}) → TResult

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ConfirmP24PaymentData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(P24PaymentMethodDetails? paymentMethod, String? returnUrl, PaymentIntentSetupFutureUsage? setupFutureUsage)) → TResult

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(P24PaymentMethodDetails? paymentMethod, String? returnUrl, PaymentIntentSetupFutureUsage? setupFutureUsage)?) → TResult?

Available on ConfirmP24PaymentData, provided by the ConfirmP24PaymentDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited