ConfirmSepaDebitPaymentData class abstract

Available extensions
Annotations
  • @freezed

Constructors

ConfirmSepaDebitPaymentData({@paymentMethodDetailJsonKey SepaDebitPaymentMethodDetails? paymentMethod, @JsonKey.new(name: "setup_future_usage") PaymentIntentSetupFutureUsage? setupFutureUsage})
const
factory
ConfirmSepaDebitPaymentData.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ConfirmSepaDebitPaymentDataCopyWith<ConfirmSepaDebitPaymentData>
Create a copy of ConfirmSepaDebitPaymentData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paymentMethod → SepaDebitPaymentMethodDetails?
Either the id of an existing PaymentMethod, or an object containing data to create a PaymentMethod with. See the use case sections below for details.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupFutureUsage → PaymentIntentSetupFutureUsage?
To set up the SEPA Direct Debit account for reuse, set this parameter to off_session. SEPA Direct Debit only accepts an off_session value for this parameter. If a customer is provided on this PaymentIntent, the PaymentMethod will be attached to the customer when the PaymentIntent transitions to processing.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ConfirmSepaDebitPaymentData value)) → TResult

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ConfirmSepaDebitPaymentData value)?) → TResult?

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ConfirmSepaDebitPaymentData value)?, {required TResult orElse()}) → TResult

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(SepaDebitPaymentMethodDetails? paymentMethod, PaymentIntentSetupFutureUsage? setupFutureUsage)?, {required TResult orElse()}) → TResult

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ConfirmSepaDebitPaymentData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(SepaDebitPaymentMethodDetails? paymentMethod, PaymentIntentSetupFutureUsage? setupFutureUsage)) → TResult

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(SepaDebitPaymentMethodDetails? paymentMethod, PaymentIntentSetupFutureUsage? setupFutureUsage)?) → TResult?

Available on ConfirmSepaDebitPaymentData, provided by the ConfirmSepaDebitPaymentDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited