CreatePaymentMethodData class

Annotations
  • @freezed

Constructors

CreatePaymentMethodData({required String type, @ElementConverter.new() Element? card, @ElementConverter.new() Element? auBecsDebit, @ElementConverter.new() Element? fpx, String? fpxBank, String? netbankingBank, @ElementConverter.new() Element? ideal, String? idealBank, @ElementConverter.new() Element? sepaDebit, String? sepaDebitIban, String? upiVpa, BillingDetails? billingDetails})
const
factory
CreatePaymentMethodData.fromJson(Map<String, dynamic> json)
factory

Properties

auBecsDebit → Element?
An auBankAccount Element.
no setterinherited
billingDetails → BillingDetails?
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
no setterinherited
card → Element?
A card or cardNumber Element.
no setterinherited
copyWith → $CreatePaymentMethodDataCopyWith<CreatePaymentMethodData>
Create a copy of CreatePaymentMethodData with the given fields replaced by the non-null parameter values.
no setterinherited
fpx → Element?
An fpx Element.
no setterinherited
fpxBank → String?
The customer's bank.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ideal → Element?
An idealBank Element.
no setterinherited
idealBank → String?
The customer's bank.
no setterinherited
netbankingBank → String?
The customer's bank.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sepaDebit → Element?
An iban Element.
no setterinherited
sepaDebitIban → String?
An IBAN account number.
no setterinherited
type → String
Unique identifier for the object.
no setterinherited
upiVpa → String?
The customer's VPA.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CreatePaymentMethodData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited