CreateTokenBankAccountData class

Annotations
  • @freezed

Constructors

CreateTokenBankAccountData({required String country, required String currency, String? routingNumber, required String accountNumber, String? accountHolderName, BankAccountHolderType? accountHolderType, String? accountType})
const
factory
CreateTokenBankAccountData.fromJson(Map<String, dynamic> json)
factory

Properties

accountHolderName → String?
no setterinherited
accountHolderType → BankAccountHolderType?
no setterinherited
accountNumber → String
no setterinherited
accountType → String?
no setterinherited
copyWith → $CreateTokenBankAccountDataCopyWith<CreateTokenBankAccountData>
Create a copy of CreateTokenBankAccountData with the given fields replaced by the non-null parameter values.
no setterinherited
country → String
no setterinherited
currency → String
Three character currency code (e.g., usd).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
routingNumber → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CreateTokenBankAccountData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited