CreateTokenCardData class

Annotations
  • @freezed

Constructors

CreateTokenCardData({String? name, String? addressLine1, String? addressLine2, String? addressCity, String? addressState, String? addressZip, String? addressCountry, String? currency})
const
factory
CreateTokenCardData.fromJson(Map<String, dynamic> json)
factory

Properties

addressCity → String?
City/District/Suburb/Town/Village.
no setterinherited
addressCountry → String?
RECOMMENDED. A two character country code (for example, US). Billing address country
no setterinherited
addressLine1 → String?
Address line 1 (Street address/PO Box/Company name).
no setterinherited
addressLine2 → String?
Address line 2 (Apartment/Suite/Unit/Building).
no setterinherited
addressState → String?
State/County/Province/Region.
no setterinherited
addressZip → String?
ZIP or postal code.
no setterinherited
copyWith → $CreateTokenCardDataCopyWith<CreateTokenCardData>
Create a copy of CreateTokenCardData with the given fields replaced by the non-null parameter values.
no setterinherited
currency → String?
Required in order to add the card to a Connect account (in all other cases, this parameter is not used).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
RECOMMENDED Cardholder name.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CreateTokenCardData to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited