ExpressCheckoutLayout class

Layout parameters of the express checkout element

Annotations
  • @freezed

Constructors

ExpressCheckoutLayout({int? maxColumns, int? maxRows, ExpressCheckoutOverflow? overflow})
const
factory
ExpressCheckoutLayout.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ExpressCheckoutLayoutCopyWith<ExpressCheckoutLayout>
Create a copy of ExpressCheckoutLayout with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
maxColumns → int?
no setterinherited
maxRows → int?
no setterinherited
overflow → ExpressCheckoutOverflow?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ExpressCheckoutLayout to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited