copyWith property
Create a copy of Fpx with the given fields replaced by the non-null parameter values.
Implementation
@JsonKey(includeFromJson: false, includeToJson: false)
$FpxCopyWith<Fpx> get copyWith => throw _privateConstructorUsedError;
Create a copy of Fpx with the given fields replaced by the non-null parameter values.
@JsonKey(includeFromJson: false, includeToJson: false)
$FpxCopyWith<Fpx> get copyWith => throw _privateConstructorUsedError;