PaymentElementOptions class

Annotations
  • @freezed

Constructors

PaymentElementOptions({PaymentElementLayout? layout, PaymentElementDefaultValues? defaultValues, PaymentElementBusiness? business, dynamic paymentMethodOrder, PaymentElementFields? fields, bool? readOnly, PaymentElementOptionsTerms? terms, PaymentElementWalletOptions? wallets, PaymentElementApplePayOptions? applePay})
const
factory
PaymentElementOptions.fromJson(Map<String, dynamic> json)
factory

Properties

applePay → PaymentElementApplePayOptions?
no setterinherited
business → PaymentElementBusiness?
Provide information about your business that will be displayed in the Payment Element. This information will be retrieved from your Stripe account if not provided.
no setterinherited
copyWith → $PaymentElementOptionsCopyWith<PaymentElementOptions>
Create a copy of PaymentElementOptions with the given fields replaced by the non-null parameter values.
no setterinherited
defaultValues → PaymentElementDefaultValues?
Provide initial customer information that will be displayed in the Payment Element. The form will render with empty fields if not provided.
no setterinherited
fields → PaymentElementFields?
By default, the Payment Element will collect all necessary details to complete a payment.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
layout → PaymentElementLayout?
no setterinherited
paymentMethodOrder → dynamic
no setterinherited
readOnly → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms → PaymentElementOptionsTerms?
no setterinherited
wallets → PaymentElementWalletOptions?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PaymentElementOptions to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited