PaymentIntentCaptureMethod enum

Controls when the funds will be captured from the customer’s account.

Inheritance
Available extensions

Values

automatic → const PaymentIntentCaptureMethod

(Default) Stripe automatically captures funds when the customer authorizes the payment.

automaticAsync → const PaymentIntentCaptureMethod

Asynchronously capture funds when the customer authorizes the payment. Note: Recommended over automatic due to improved latency, but may require additional integration changes. Seealso: https://stripe.com/docs/payments/payment-intents/asynchronous-capture-automatic-async

manual → const PaymentIntentCaptureMethod

Place a hold on the funds when the customer authorizes the payment, but don’t capture the funds until later. (Not all payment methods support this.)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PaymentIntentCaptureMethod>
A constant List of the values in this enum, in order of their declaration.