PaymentMethodDataCardFromMethod class

Payment method data object for card from payment method.

Annotations
  • @freezed

Constructors

PaymentMethodDataCardFromMethod({required String paymentMethodId, String? cvc, BillingDetails? billingDetails, ShippingDetails? shippingDetails})
const
factory
PaymentMethodDataCardFromMethod.fromJson(Map<String, dynamic> json)
factory

Properties

billingDetails → BillingDetails?
Billing information.
no setterinherited
copyWith → $PaymentMethodDataCardFromMethodCopyWith<PaymentMethodDataCardFromMethod>
Create a copy of PaymentMethodDataCardFromMethod with the given fields replaced by the non-null parameter values.
no setterinherited
cvc → String?
Cvc of the cart
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paymentMethodId → String
Payment method id.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingDetails → ShippingDetails?
Shipping details
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PaymentMethodDataCardFromMethod to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited