PaymentMethodDataSepa class

Payment method data object for Sepa debit payment method.

Annotations
  • @freezed

Constructors

PaymentMethodDataSepa({required String iban, BillingDetails? billingDetails, ShippingDetails? shippingDetails})
const
factory
PaymentMethodDataSepa.fromJson(Map<String, dynamic> json)
factory

Properties

billingDetails → BillingDetails?
Billing information.
no setterinherited
copyWith → $PaymentMethodDataSepaCopyWith<PaymentMethodDataSepa>
Create a copy of PaymentMethodDataSepa with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iban → String
Iban number of the accountholder
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingDetails → ShippingDetails?
Shipping details
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PaymentMethodDataSepa to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited