PaymentMethodDataUsBank class

Payment method data object forUsbankaccount payment method.

Annotations
  • @freezed

Constructors

PaymentMethodDataUsBank({String? accountNumber, String? routingNumber, UsBankAccountHolderType? accountHolderType, UsBankAccountType? accountType, BillingDetails? billingDetails, ShippingDetails? shippingDetails})
const
factory
PaymentMethodDataUsBank.fromJson(Map<String, dynamic> json)
factory

Properties

accountHolderType → UsBankAccountHolderType?
The bank account type of the holder
no setterinherited
accountNumber → String?
The account number of the bank account.
no setterinherited
accountType → UsBankAccountType?
The account type
no setterinherited
billingDetails → BillingDetails?
Billing information.
no setterinherited
copyWith → $PaymentMethodDataUsBankCopyWith<PaymentMethodDataUsBank>
Create a copy of PaymentMethodDataUsBank with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
routingNumber → String?
The routing number, sort code, or other country-appropriate institution number for the bank account.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingDetails → ShippingDetails?
Shipping details
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PaymentMethodDataUsBank to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited