SepaBillingDetails class abstract

Billing information associated with the payment method.

Available extensions
Annotations
  • @freezed

Constructors

SepaBillingDetails({required String email, BillingAddress? address, String? phone, required String name})
const
factory
SepaBillingDetails.fromJson(Map<String, dynamic> json)
factory

Properties

address → BillingAddress?
Billing address.
no setterinherited
copyWith → $SepaBillingDetailsCopyWith<SepaBillingDetails>
Create a copy of SepaBillingDetails with the given fields replaced by the non-null parameter values.
no setterinherited
email → String
Email address.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Full name.
no setterinherited
phone → String?
Billing phone number.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SepaBillingDetails value)) → TResult

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SepaBillingDetails value)?) → TResult?

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SepaBillingDetails value)?, {required TResult orElse()}) → TResult

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String email, BillingAddress? address, String? phone, String name)?, {required TResult orElse()}) → TResult

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SepaBillingDetails to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String email, BillingAddress? address, String? phone, String name)) → TResult

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String email, BillingAddress? address, String? phone, String name)?) → TResult?

Available on SepaBillingDetails, provided by the SepaBillingDetailsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited