SetupIntentResponse class

Annotations
  • @freezed

Constructors

SetupIntentResponse({SetupIntent? setupIntent, StripeError? error})
const
factory
SetupIntentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SetupIntentResponseCopyWith<SetupIntentResponse>
Create a copy of SetupIntentResponse with the given fields replaced by the non-null parameter values.
no setterinherited
error → StripeError?
If not null, an error occurred
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setupIntent → SetupIntent?
If not null, a SetupIntent was retrieved successfully
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SetupIntentResponse to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited