UsBankAccount class

Data associated with the payment method Us bank account.

Annotations
  • @freezed

Constructors

UsBankAccount({String? routingNumber, String? last4, required UsBankAccountHolderType accountHolderType, required UsBankAccountType accountType, String? bankName, String? fingerprint, String? linkedAccount, List<String>? preferredNetworks, List<String>? supportedNetworks})
const
factory
UsBankAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountHolderType → UsBankAccountHolderType
The bank account type of the holder
no setterinherited
accountType → UsBankAccountType
The account type
no setterinherited
bankName → String?
The name of the bank of the account
no setterinherited
copyWith → $UsBankAccountCopyWith<UsBankAccount>
Create a copy of UsBankAccount with the given fields replaced by the non-null parameter values.
no setterinherited
fingerprint → String?
Unique identifier for the bankaccount.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
last4 → String?
Last 4 digits of the account
no setterinherited
linkedAccount → String?
Number of linkedaccount
no setterinherited
preferredNetworks → List<String>?
list of preferred network names
no setterinherited
routingNumber → String?
Routing number of the bank account
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedNetworks → List<String>?
list of preferred network names
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UsBankAccount to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited