VerifyMicrodepositsForPaymentData class abstract

Available extensions
Annotations
  • @freezed

Constructors

VerifyMicrodepositsForPaymentData({List<int>? amounts, @JsonKey.new(name: 'descriptor_code') String? descriptorCode})
const
factory
VerifyMicrodepositsForPaymentData.fromJson(Map<String, dynamic> json)
factory

Properties

amounts List<int>?
The amounts of the microdeposits that were deposited on the customer's bank account. Must contain exactly 2 values. Mutually exclusive with descriptorCode.
no setterinherited
copyWith → $VerifyMicrodepositsForPaymentDataCopyWith<VerifyMicrodepositsForPaymentData>
Create a copy of VerifyMicrodepositsForPaymentData with the given fields replaced by the non-null parameter values.
no setterinherited
descriptorCode String?
The descriptor code from the microdeposit to the customer's bank account. Mutually exclusive with amounts.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VerifyMicrodepositsForPaymentData value)) → TResult

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VerifyMicrodepositsForPaymentData value)?) → TResult?

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VerifyMicrodepositsForPaymentData value)?, {required TResult orElse()}) → TResult

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<int>? amounts, String? descriptorCode)?, {required TResult orElse()}) → TResult

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this VerifyMicrodepositsForPaymentData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<int>? amounts, String? descriptorCode)) → TResult

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<int>? amounts, String? descriptorCode)?) → TResult?

Available on VerifyMicrodepositsForPaymentData, provided by the VerifyMicrodepositsForPaymentDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited