ExtensionConfirmPayment extension

on

Methods

confirmPayment(ConfirmPaymentOptions options) Future<PaymentIntentResponse>

Available on Stripe, provided by the ExtensionConfirmPayment extension

Use stripe.confirmPayment to confirm a PaymentIntent using data collected by the Payment Element. When called, stripe.confirmPayment will attempt to complete any required actions, such as authenticating your user by displaying a 3DS dialog or redirecting them to a bank authorization page. Your user will be redirected to the return_url you pass once the confirmation is complete.