descriptorCode property
The descriptor code from the microdeposit to the customer's
bank account. Mutually exclusive with amounts.
Implementation
List<int>? get amounts;/// The descriptor code from the microdeposit to the customer's
/// bank account. Mutually exclusive with [amounts].
@JsonKey(name: 'descriptor_code') String? get descriptorCode;