ExtensionConfirmSetup extension
- on
Methods
-
confirmSetup(
ConfirmSetupOptions options) → Future< SetupIntentResponse> -
Available on Stripe, provided by the ExtensionConfirmSetup extension
Use stripe.confirmSetup to confirm a SetupIntent using data collected by the Payment Element, or with manually provided data via confirmParams. When called, stripe.confirmSetup will attempt to complete any required actions, such as authenticating your user by displaying a 3DS dialog or redirecting them to a bank authorization page. Your user will be redirected to the return_url you pass once the authorization is complete.